summaryrefslogtreecommitdiffstats
path: root/kshowmail/configlist.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
commit9c02dbb59ce57c68dc177d9294b980bf114a3e11 (patch)
treeb1b40423c9be9a42a97cd0e8f3af3139aefb6fa0 /kshowmail/configlist.h
parent0b875800e452c97b1a3f25aba5f029a8c33a4b93 (diff)
downloadkshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.tar.gz
kshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.zip
Update to TDE R14 API
Diffstat (limited to 'kshowmail/configlist.h')
-rw-r--r--kshowmail/configlist.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kshowmail/configlist.h b/kshowmail/configlist.h
index 97418cd..158c665 100644
--- a/kshowmail/configlist.h
+++ b/kshowmail/configlist.h
@@ -22,10 +22,10 @@
#ifndef CONFIGLIST_H
#define CONFIGLIST_H
-//Qt header
-#include <qptrlist.h>
-#include <qlistview.h>
-#include <qobject.h>
+//TQt header
+#include <ntqptrlist.h>
+#include <ntqlistview.h>
+#include <ntqobject.h>
//KDE headers
#include <kcombobox.h>
@@ -38,7 +38,7 @@
#include "kshowmailview.h"
#include "types.h"
#include "encryption.h"
-#include "kwalletaccess.h"
+#include "tdewalletaccess.h"
#include "filteritem.h"
#include "headerfilter.h"
#include "filterlog.h"
@@ -56,7 +56,7 @@ class KshowmailView;
* @author Eggert Ehmke
* @author Ulrich Weigelt
*/
-class ConfigList : public QObject, public QPtrList<ConfigElem>
+class ConfigList : public TQObject, public TQPtrList<ConfigElem>
{
Q_OBJECT
@@ -78,7 +78,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
* sets the properties.
* @param view pointer to the account list view
*/
- void refreshSetup( KListView* view );
+ void refreshSetup( TDEListView* view );
/**
* Reloads the filter settings
@@ -217,7 +217,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
* Returns the subjects of the selected mails.
* @return subjects of selected mails
*/
- QStringList getSelectedSubjects() const;
+ TQStringList getSelectedSubjects() const;
/**
* Returns whether there are mails in this list which are selected
@@ -377,7 +377,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
* Returns the mailbox for spam mails
* @return mailbox for spam
*/
- QString getSpamMailbox();
+ TQString getSpamMailbox();
/**
* Returns the number of deleted mails by last refresh.
@@ -413,10 +413,10 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
* Returns the senders of the selected mails
* @return senders of the selected mails
*/
- QStringList getSelectedSenders() const;
+ TQStringList getSelectedSenders() const;
bool setItem (const char* item);
- void setList (QListView* list);
+ void setList (TQListView* list);
void beep ();
void playSound ();
void playSound (const char* file);
@@ -427,7 +427,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
/**
* Connector to the configuration file
*/
- KConfig* config;
+ TDEConfig* config;
/**
* Time in minutes to the next automatic refresh.
@@ -530,7 +530,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
/**
* Sound file which will be played if a new mail is arrived.
*/
- QString m_strSoundFile;
+ TQString m_strSoundFile;
/**
* TRUE - If a new mail is arrived a command will be executed.
@@ -540,7 +540,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
/**
* Path to command which will be executed if a new mail is arrived.
*/
- QString m_strCommandPath;
+ TQString m_strCommandPath;
/**
* TRUE - If no new mail is arrived the application will be ended.
@@ -585,7 +585,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
/**
* Mailbox for Spam, if configured
*/
- QString spamMailbox;
+ TQString spamMailbox;
/**
* Action which shall be done, if the mail is Spam
@@ -597,22 +597,22 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
/**
* Makes a copy from the given account object and returns the pointer to it.
* Reimplementation of QPtrList::newItem().
* Used by QPtrList to add new items.
* @param item account object
* @return pointer to the new account object
*/
- virtual QCollection::Item newItem( QCollection::Item item );
+ virtual TQCollection::Item newItem( TQCollection::Item item );
/**
* Compares two ConfigElem objects.
* Reimplementation of QPtrList::compareItems(). Used by inSort().
* @param item1 account 1
* @param item2 account 2
* @return 0 if account name 1 == account name 2
* @return nonzero if account name 2 != account name 2
*/
- virtual int compareItems( QCollection::Item item1, QCollection::Item item2 );
+ virtual int compareItems( TQCollection::Item item1, TQCollection::Item item2 );
/**
* Returns whether the given account is in the list
@@ -620,14 +620,14 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
* @return TRUE - account is existent
* @return FALSE - account is not existent
*/
- bool hasAccount( const QString& name ) const;
+ bool hasAccount( const TQString& name ) const;
/**
* Returns the pointer to the account named like the given name.
* @param name of the searched account
* @return account or NULL, if the account was not found
*/
- ConfigElem* getAccount( const QString& name ) const;
+ ConfigElem* getAccount( const TQString& name ) const;
protected slots:
@@ -646,7 +646,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
* @param account name of the account which has emitted the signal
* @see AccountDeletionMap
*/
- void slotCheckDeletionState( QString account );
+ void slotCheckDeletionState( TQString account );
/**
* Connected with signal sigShowBodiesReady of all accounts.
@@ -657,7 +657,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
* @param account name of the account which has emitted the signal
* @see AccountShowBodiesMap
*/
- void slotCheckShowBodiesState( QString account );
+ void slotCheckShowBodiesState( TQString account );
/**
* Connected with signal sigMessageWindowOpened of all accounts.
@@ -690,7 +690,7 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
* @param account name of the account which has emitted the signal
* @see AccountRefreshMap
*/
- void slotCheckRefreshState( QString account );
+ void slotCheckRefreshState( TQString account );
signals:
@@ -597,22 +597,22 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
/**
* Makes a copy from the given account object and returns the pointer to it.
- * Reimplementation of QPtrList::newItem().
- * Used by QPtrList to add new items.
+ * Reimplementation of TQPtrList::newItem().
+ * Used by TQPtrList to add new items.
* @param item account object
* @return pointer to the new account object
@@ -597,22 +597,22 @@ class ConfigList : public QObject, public QPtrList<ConfigElem>
/**
* Compares two ConfigElem objects.
- * Reimplementation of QPtrList::compareItems(). Used by inSort().
+ * Reimplementation of TQPtrList::compareItems(). Used by inSort().
* @param item1 account 1
* @param item2 account 2